@@ -6,9 +6,9 @@ from typing import Any, Dict, List, Optional, Tuple
 
 import numpy as np
 import pandas as pd
-import six
+import six  # type: ignore
 
-try:
+try:  # pragma: no cover
     from ciso8601 import parse_datetime
 
     _HAS_CISO8601 = True
